# Generated by Django 2.2.20 on 2021-09-23 19:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('turkle', '0011_add_turkle_user_admin_group'),
    ]

    operations = [
        migrations.AlterField(
            model_name='taskassignment',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, db_index=True),
        ),
    ]
