{% extends "admin/base_site.html" %}

{% block content %}
<p>Turkle is a Mechanical Turk-compatible web application for collecting annotations.</p>
<dl>
  <dt>Version</dt>
  <dd>{{ version }}</dd>
</dl>
{% endblock %}
