{% extends "turkle/base.html" %}
{% load i18n static %}

{# This is shown to annotators and for admin site #}

{% block body %}

<div class="container-fluid mt-3">
  {% block content %}

  {% if form.non_field_errors %}
    {% for error in form.non_field_errors %}
    <div class="alert alert-error" role="alert">
      <h5 class="card-title" align="center">{{ error }}</h5>
    </div>
    {% endfor %}
  {% endif %}

  <form method="post" class="col-md-6 offset-md-3">
  {% csrf_token %}
  {% block content_title %}<h1>{{ title }}</h1>{% endblock %}
    <p>{% trans "Enter your current password and your new password twice for verification." %}</p>
    <div class="panel panel-primary">
      {% for field in form %}
      {% include 'registration/form_field.html' %}
      {% endfor %}
      {{ form.new_password1.help_text|safe }}
      <div class="form-group">
        <input type="submit" value="Change my password" class="btn btn-primary" />
      </div>
    </div>
  </form>

  {% endblock %}
</div>

{% endblock %}
