# -*- coding: utf-8 -*-
# Generated by Django 1.11.23 on 2019-11-22 14:38
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('turkle', '0004_batch_login_required'),
    ]

    operations = [
        migrations.AddField(
            model_name='batch',
            name='published',
            field=models.BooleanField(db_index=True, default=True),
        ),
    ]
